package javax.swing.plaf;

import javax.accessibility.Accessible;
import javax.swing.SwingUtilities;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics;
import javax.swing.JComponent;

public abstract class ComponentUI
{
    public ComponentUI() {
    }
    
    public void installUI(JComponent component) {
    }
    
    public void uninstallUI(JComponent component) {
    }
    
    public void paint(Graphics graphics, JComponent component) {
    }
    
    public void update(Graphics graphics, JComponent component) {
        if (component.isOpaque()) {
            graphics.setColor(component.getBackground());
            graphics.fillRect(0, 0, component.getWidth(), component.getHeight());
        }
        this.paint(graphics, component);
    }
    
    public Dimension getPreferredSize(JComponent component) {
        return null;
    }
    
    public Dimension getMinimumSize(JComponent component) {
        return this.getPreferredSize(component);
    }
    
    public Dimension getMaximumSize(JComponent component) {
        return this.getPreferredSize(component);
    }
    
    public boolean contains(JComponent component, int x, int y) {
        return component.inside(x, y);
    }
    
    public static ComponentUI createUI(JComponent component) {
        throw new Error("ComponentUI.createUI not implemented.");
    }
    
    public int getBaseline(JComponent component, int n, int n2) {
        if (component == null) {
            throw new NullPointerException("Component must be non-null");
        }
        if (n < 0 || n2 < 0) {
            throw new IllegalArgumentException("Width and height must be >= 0");
        }
        return -1;
    }
    
    public Component.BaselineResizeBehavior getBaselineResizeBehavior(JComponent component) {
        if (component == null) {
            throw new NullPointerException("Component must be non-null");
        }
        return Component.BaselineResizeBehavior.OTHER;
    }
    
    public int getAccessibleChildrenCount(JComponent c) {
        return SwingUtilities.getAccessibleChildrenCount(c);
    }
    
    public Accessible getAccessibleChild(JComponent c, int i) {
        return SwingUtilities.getAccessibleChild(c, i);
    }
}
